function [Eads,bsseCorrection]=ORCA_UPDATE(gasfile,freecluster,...
    cluster,gasfileQZ,freeclusterQZ,clusterQZ,formatBSSE,N)
% .m script to extract thermochemisty data from ORCA,
% processing output files for T=25,200,400 deg Celsius
%
% AUTHOR: JAIME GARRIDO ALDEA AND MARA PILAR DE LARA CASTELLS, 2022
%
% INPUTS:
%     -GASFILE: name of the ORCA .out file of the free gas.
%     -FREECLUSTER: name of the ORCA .out file of the cluster with no gas molecules-
%     -CLUSTER: name of the ORCA .out file of the cluster with gas molecules
%     -N: number of adsorbants molecules;
%     -REMARKS: INCLUDE THE .out extension!!!!
%
%
% 
%-------------------------------------------------------------------------------
gasfile=fopen(gasfile);
gasfileQZ=fopen(gasfileQZ);
freecluster=fopen(freecluster);
cluster=fopen(cluster);
freeclusterQZ=fopen(freeclusterQZ);
clusterQZ=fopen(clusterQZ);


%-------------------------READING FOR
%TZ-----------------------------------
line=fgetl(cluster);
line=fgetl(cluster);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        EclusterTZ=str2double(splitLine(5));
    end
    line=fgetl(cluster);
end
line=fgetl(freecluster);
line=fgetl(freecluster);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        EfreeclusterTZ=str2double(splitLine(5));
    end
    line=fgetl(freecluster);
end

line=fgetl(gasfile);
line=fgetl(gasfile);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        EgasTZ=str2double(splitLine(5));
    end
    line=fgetl(gasfile);
end
%--------------------------------------------------------------------------

%--------------------------READING FOR QZ---------------------------------

line=fgetl(clusterQZ);
line=fgetl(clusterQZ);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        EclusterQZ=str2double(splitLine(5));
    end
    line=fgetl(clusterQZ);
end
line=fgetl(freeclusterQZ);
line=fgetl(freeclusterQZ);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        EfreeclusterQZZ=str2double(splitLine(5));
    end
    line=fgetl(freeclusterQZ);
end

line=fgetl(gasfileQZ);
line=fgetl(gasfileQZ);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        EgasQZ=str2double(splitLine(5));
    end
    line=fgetl(gasfileQZ);
end
EadsQZ=(EclusterQZ-EfreeclusterQZZ-N*EgasQZ)
EadsTZ=EclusterTZ-EfreeclusterTZ-N*EgasTZ
Eads=abs(EadsQZ-EadsTZ);


%-------------------------------READING FOR
%BSSE-----------------------------

BSSE1=strcat(formatBSSE,'1.out');
BSSE2=strcat(formatBSSE,'2.out');
BSSE3=strcat(formatBSSE,'3.out');
BSSE4=strcat(formatBSSE,'4.out');

BSSE1=fopen(BSSE1);
BSSE2=fopen(BSSE2);
BSSE3=fopen(BSSE3);
BSSE4=fopen(BSSE4);

line=fgetl(BSSE1);
line=fgetl(BSSE1);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        Ebsse1=str2double(splitLine(5));
    end
    line=fgetl(BSSE1);
end

line=fgetl(BSSE2);
line=fgetl(BSSE2);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        Ebsse2=str2double(splitLine(5));
    end
    line=fgetl(BSSE2);
end

line=fgetl(BSSE3);
line=fgetl(BSSE3);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        Ebsse3=str2double(splitLine(5));
    end
    line=fgetl(BSSE3);
end

line=fgetl(BSSE4);
line=fgetl(BSSE4);
while (all(not(line==-1)) || isempty(line))
    if startsWith(line,'FINAL SINGLE POINT ENERGY')
        splitLine=strsplit(line);
        Ebsse4=str2double(splitLine(5));
    end
    line=fgetl(BSSE4);
end
bsseCorrection=abs(Ebsse1-Ebsse2+Ebsse3-Ebsse4);
end

